@@ -37,7 +37,10 @@ from sqlalchemy.orm.session import Session
 import nowcasting_forecast
 from nowcasting_forecast import N_GSP
 from nowcasting_forecast.dataloader import BatchDataLoader
-from nowcasting_forecast.models.sun import filter_forecasts_on_sun_elevation
+from nowcasting_forecast.models.sun import (
+    drop_forecast_on_sun_elevation,
+    filter_forecasts_on_sun_elevation,
+)
 from nowcasting_forecast.utils import floor_minutes_dt
 
 logger = logging.getLogger(__name__)
@@ -191,6 +194,7 @@ def convert_one_gsp_id_to_forecast_sql(
         forecast_creation_time=forecast_creation_time,
         forecast_values=forecast_values,
         input_data_last_updated=input_data_last_updated,
+        historic=False,
     )
 
     # validate
@@ -284,6 +288,9 @@ def general_forecast_run_all_batches(
     # filter forecast for sun
     forecast_sql = filter_forecasts_on_sun_elevation(forecasts=forecast_sql)
 
+    # filter forecast for nighttime
+    forecast_sql = drop_forecast_on_sun_elevation(forecasts=forecast_sql, session=session)
+
     # select first 338 forecast
     if len(forecast_sql) > N_GSP:
         logger.debug(
